@@ -579,7 +579,7 @@ interactive_select_packages() {
 
     # show group listing for group selection, base is ON by default, all others are OFF
     local _catlist="base ^ ON"
-    for i in $($PACMAN -Sg | sed "s/^base$/ /g"); do
+    for i in $($PACMAN_TARGET -Sg | sed "s/^base$/ /g"); do
         _catlist="${_catlist} ${i} - OFF"
     done
 
@@ -588,10 +588,10 @@ interactive_select_packages() {
 
     # assemble a list of packages with groups, marking pre-selected ones
     # <package> <group> <selected>
-    local _pkgtmp="$($PACMAN -Sl core | awk '{print $2}')" # all packages in core repository
+    local _pkgtmp="$($PACMAN_TARGET -Sl core | awk '{print $2}')" # all packages in core repository
     local _pkglist=''
 
-    $PACMAN -Si $_pkgtmp | awk '/^Name/{ printf("%s ",$3) } /^Group/{ print $3 }' > $ANSWER
+    $PACMAN_TARGET -Si $_pkgtmp | awk '/^Name/{ printf("%s ",$3) } /^Group/{ print $3 }' > $ANSWER
     while read pkgname pkgcat; do
         # check if this package is in a selected group
         # slightly ugly but sorting later requires newlines in the variable
